@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-#use lib '../blib/lib', '../blib/arch';
+use lib '../blib/lib', '../blib/arch';
 
 ### calculate_precision_and_recall_for_LSA.pl
 
@@ -30,25 +30,27 @@ my $relevancy_file   = "relevancy.txt";        # The generated relevancies will
                                                # be stored in this file.
 
 my $lsa = Algorithm::VSM->new( 
+                   break_camelcased_and_underscored  => 1,  # default: 0
+                   case_sensitive      => 0,                # default: 0 
                    corpus_directory    => $corpus_dir,
-                   stop_words_file     => $stop_words_file,
-                   query_file          => $query_file,
-                   want_stemming       => 1,
-                   break_camelcased_and_underscored  => 1,
-                   min_word_length     => 4,
+                   file_types          => ['.txt', '.java'],
                    lsa_svd_threshold   => 0.05,     # Used for rejecting singular
                                                     # values that are smaller than
                                                     # this threshold fraction of
                                                     # the largest singular value.
+                   min_word_length     => 4,
+                   query_file          => $query_file,
+                   relevancy_file      => $relevancy_file,   # Relevancy judgments
+                                                             # are deposited in 
+                                                             # this file.
                    relevancy_threshold => 5,    # Used when estimating relevancies
                                                 # with the method 
                                                 # estimate_doc_relevancies().  A
                                                 # doc must have at least this 
                                                 # number of query words to be
                                                 # considered relevant.
-                   relevancy_file      => $relevancy_file,   # Relevancy judgments
-                                                             # are deposited in 
-                                                             # this file.
+                   stop_words_file     => $stop_words_file,
+                   want_stemming       => 1,                # default: 0
           );
 
 $lsa->get_corpus_vocabulary_and_word_counts();
