@@ -1,8 +1,8 @@
 #!/usr/bin/perl -w
 
-#use lib '../blib/lib', '../blib/arch';
+use lib '../blib/lib', '../blib/arch';
 
-### calculate_precision_and_recall_for_VSM.pl
+##  calculate_precision_and_recall_for_VSM.pl
 
 use strict;
 use Algorithm::VSM;
@@ -29,21 +29,23 @@ my $relevancy_file   = "relevancy.txt";        # The generated relevancies will
                                                # be stored in this file.
 
 my $vsm = Algorithm::VSM->new( 
+                   break_camelcased_and_underscored  => 1,  #default: 1
+                   case_sensitive      => 0,                # default: 0 
                    corpus_directory    => $corpus_dir,
-                   stop_words_file     => $stop_words_file,
-                   query_file          => $query_file,
-                   want_stemming       => 1,
+                   file_types          => ['.txt', '.java'],
                    min_word_length     => 4,
-                   break_camelcased_and_underscored  => 1,  #default is 1
+                   query_file          => $query_file,
+                   relevancy_file      => $relevancy_file,   # Relevancy judgments
+                                                             # are deposited in 
+                                                             # this file.
                    relevancy_threshold => 5,    # Used when estimating relevancies
                                                 # with the method 
                                                 # estimate_doc_relevancies().  A
                                                 # doc must have at least this 
                                                 # number of query words to be
                                                 # considered relevant.
-                   relevancy_file      => $relevancy_file,   # Relevancy judgments
-                                                             # are deposited in 
-                                                             # this file.
+                   stop_words_file     => $stop_words_file,
+                   want_stemming       => 1,                # default: 0
           );
 
 $vsm->get_corpus_vocabulary_and_word_counts();
