@@ -1,8 +1,8 @@
 #!/usr/bin/perl -w
 
-#use lib '../blib/lib', '../blib/arch';
+use lib '../blib/lib', '../blib/arch';
 
-### calculate_precision_and_recall_from_file_based_relevancies_for_LSA.pl
+##  calculate_precision_and_recall_from_file_based_relevancies_for_LSA.pl
 
 ##  This script looks for human-supplied relevancy judgments in a file called
 ##  `relevancy.txt' for the queries in the file `test_queries.txt'
@@ -29,17 +29,19 @@ my $relevancy_file   = "relevancy.txt";        # The humans-supplied relevancies
                                                # will be read from this file.
 
 my $lsa = Algorithm::VSM->new( 
+                   break_camelcased_and_underscored  => 1,  # default: 1
+                   case_sensitive      => 0,                # default: 0 
                    corpus_directory    => $corpus_dir,
-                   stop_words_file     => $stop_words_file,
-                   query_file          => $query_file,
-                   want_stemming       => 1,
-                   min_word_length     => 4,
-                   break_camelcased_and_underscored  => 1,  #default is 1
+                   file_types          => ['.txt', '.java'],
                    lsa_svd_threshold   => 0.01,     # Used for rejecting singular
                                                     # values that are smaller than
                                                     # this threshold fraction of
                                                     # the largest singular value.
+                   min_word_length     => 4,
+                   query_file          => $query_file,
                    relevancy_file      => $relevancy_file,
+                   stop_words_file     => $stop_words_file,
+                   want_stemming       => 1,                # default: 0
           );
 
 $lsa->get_corpus_vocabulary_and_word_counts();
