@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-#use lib '../blib/lib', '../blib/arch';
+use lib '../blib/lib', '../blib/arch';
 
 ### retrieve_with_VSM.pl
 
@@ -25,13 +25,15 @@ my $stop_words_file = "stop_words.txt";    # This file will typically include th
                                            # language(s) used in the software.
 
 my $vsm = Algorithm::VSM->new( 
+                   break_camelcased_and_underscored  => 1,  # default: 1
+                   case_sensitive           => 0,           # default: 0 
                    corpus_directory         => $corpus_dir,
-                   use_idf_filter           => 1,
-                   stop_words_file          => $stop_words_file,
+                   file_types               => ['.txt', '.java'],
                    max_number_retrievals    => 10,
-                   want_stemming            => 1,      # default is no stemming
                    min_word_length          => 4,
-                   break_camelcased_and_underscored  => 1,  #default is 1
+                   stop_words_file          => $stop_words_file,
+                   use_idf_filter           => 1,
+                   want_stemming            => 1,           # default: 0
           );
 
 $vsm->get_corpus_vocabulary_and_word_counts();
