@@ -1,8 +1,8 @@
 #!/usr/bin/perl -w
 
-#use lib '../blib/lib', '../blib/arch';
+use lib '../blib/lib', '../blib/arch';
 
-### retrieve_with_disk_based_VSM.pl
+##  retrieve_with_disk_based_VSM.pl
 
 use strict;
 use Algorithm::VSM;
