@@ -1,15 +1,14 @@
 package Algorithm::VSM;
 
 #---------------------------------------------------------------------------
-# Copyright (c) 2015 Avinash Kak. All rights reserved.  This program is
-# free software.  You may modify and/or distribute it under the same terms
-# as Perl itself.  This copyright notice must remain attached to the file.
+# Copyright (c) 2015 Avinash Kak. All rights reserved.  This program is free
+# software.  You may modify and/or distribute it under the same terms as Perl itself.
+# This copyright notice must remain attached to the file.
 #
-# Algorithm::VSM is a Perl module for retrieving documents from software
-# libraries that match a list of words in a query.  Document are matched
-# with queries using a similarity criterion that depends on whether your
-# model for the entire library is based on the full-dimensionality VSM or
-# on the reduced-dimensionality LSA.
+# Algorithm::VSM is a Perl module for retrieving the documents from a software
+# library that match a list of words in a query. The matching criterion used depends
+# on whether you ask the module to construct a full-dimensionality VSM or a
+# reduced-dimensionality LSA model for the library.
 # ---------------------------------------------------------------------------
 
 use 5.10.0;
@@ -19,20 +18,22 @@ use Carp;
 use SDBM_File;
 use PDL::Lite;
 use PDL::MatrixOps;
+use File::Basename;
+use File::Spec::Functions qw(rel2abs);
 use Fcntl;
 use Storable;
 use Cwd;
 
-our $VERSION = '1.60';
+our $VERSION = '1.61';
 
 # for camelcase splits (from perlmonks):
 my $_regex = qr/[[:lower:]0-9]+|[[:upper:]0-9](?:[[:upper:]0-9]+|[[:lower:]0-9]*)(?=$|[[:upper:]0-9])/; 
 
 ###################################   Constructor  #######################################
 
-#  Constructor for constructing a VSM or LSA model of a corpus.  The model
-#  instance returned by the constructor can be used for retrieving
-#  documents from the corpus in response to queries.
+#  Constructor for creating a VSM or LSA model of a corpus.  The model instance
+#  returned by the constructor can be used for retrieving documents from the corpus
+#  in response to queries.
 sub new { 
     my ($class, %args) = @_;
     my @params = keys %args;
@@ -48,15 +49,16 @@ sub new {
         _doc_vectors_db         =>  $args{doc_vectors_db} || "doc_vectors_db",
         _normalized_doc_vecs_db =>  $args{normalized_doc_vecs_db} || "normalized_doc_vecs_db",
         _stop_words_file        =>  $args{stop_words_file} || "",
+        _case_sensitive         =>  $args{case_sensitive} || 0,
         _query_file             =>  $args{query_file} || "",
+        _file_types             =>  $args{file_types} || [],
         _min_word_length        =>  $args{min_word_length} || 4,
         _want_stemming          =>  $args{want_stemming} || 0,
-        _idf_filter_option      =>  exists $args{use_idf_filter} ?
-                                          $args{use_idf_filter} : 1,
+        _idf_filter_option      =>  exists $args{use_idf_filter} ? $args{use_idf_filter} : 1,
         _max_number_retrievals  =>  $args{max_number_retrievals} || 30,
         _lsa_svd_threshold      =>  $args{lsa_svd_threshold} || 0.01,
         _relevancy_threshold    =>  exists $args{relevancy_threshold} ?
-                                                   $args{relevancy_threshold} : 1,
+                                                              $args{relevancy_threshold} : 1,
         _relevancy_file         =>  $args{relevancy_file} || "",
         _debug                  =>  $args{debug} || 0,
         _working_directory      =>  cwd,
@@ -120,8 +122,8 @@ sub get_corpus_vocabulary_and_word_counts {
     foreach (keys %{$self->{_vocab_idf_hist}}) {
         $self->{_idf_t}->{$_} = abs( (1 + log($self->{_total_num_of_docs}
                                       /
-                                     (1 + $self->{_vocab_idf_hist}->{$_}))) 
-                                   / log(10) ); 
+                                      (1 + $self->{_vocab_idf_hist}->{$_}))) 
+                                      / log(10) ); 
     }
 }
 
@@ -246,8 +248,8 @@ sub display_normalized_doc_vectors {
 
 ########################  Calculate Pairwise Document Similarities  ######################
 
-# Returns the similarity score for two documents whose actual names are
-# are supplied as its two arguments.
+# Returns the similarity score for two documents whose actual names are are supplied
+# as its two arguments.
 sub pairwise_similarity_for_docs {
     my $self = shift;
     my $doc1 = shift;
@@ -299,10 +301,13 @@ sub retrieve_with_vsm {
     my $query = shift;
     my @clean_words;
     my $min = $self->{_min_word_length};
+
     if ($self->{_break_camelcased_and_underscored}) {
         my @brokenup = grep $_, split /\W|_|\s+/, "@$query";
         @clean_words = map {$_ =~ /$_regex/g} @brokenup;
-        @clean_words = grep $_, map {$_ =~ /([[:lower:]0-9]{$min,})/i;$1?"\L$1":''} @clean_words;
+        @clean_words = $self->{_case_sensitive} ? 
+                       grep $_, map {$_ =~ /([[:lower:]0-9]{$min,})/i;$1?$1:''} @clean_words :
+                       grep $_, map {$_ =~ /([[:lower:]0-9]{$min,})/i;$1?"\L$1":''} @clean_words;
     } else {
         my @brokenup = split /\"|\'|\.|\(|\)|\[|\]|\\|\/|\s+/, "@$query";
         @clean_words = grep $_, map { /([a-z0-9_]{$min,})/i;$1 } @brokenup;
@@ -322,8 +327,11 @@ sub retrieve_with_vsm {
         $self->{_query_vector}->{$_} = 0;    
     }
     foreach (@$query) {
-        $self->{_query_vector}->{"\L$_"}++ 
-                   if exists $self->{_vocab_hist}->{"\L$_"};
+        if ($self->{_case_sensitive}) {
+            $self->{_query_vector}->{$_}++ if exists $self->{_vocab_hist}->{$_};
+        } else {
+            $self->{_query_vector}->{"\L$_"}++ if exists $self->{_vocab_hist}->{"\L$_"};
+        }
     }
     my @query_word_counts = values %{$self->{_query_vector}};
     my $query_word_count_total = reduce(\@query_word_counts);
@@ -424,7 +432,7 @@ sub display_retrievals {
 
 sub _scan_directory {
     my $self = shift;
-    my $dir = shift;
+    my $dir = rel2abs( shift );
     my $current_dir = cwd;
     chdir $dir or die "Unable to change directory to $dir: $!";
     foreach ( glob "*" ) {                                            
@@ -436,11 +444,7 @@ sub _scan_directory {
                  -T _ and 
                  -M _ > 0.00001 and  # modification age is at least 1 sec
                 !( -l $_ ) and 
-                !m{\.ps$} and 
-                !m{\.pdf$} and 
-                !m{\.eps$} and 
-                !m{\.out$} and 
-                !m{~$} ) {
+                $self->ok_to_filetype($_) ) {
             $self->_scan_file_for_rels($_) if $self->{_scan_dir_for_rels};
             $self->_scan_file($_) unless $self->{_corpus_vocab_done};
             $self->_construct_doc_vector($_) if $self->{_corpus_vocab_done};
@@ -462,7 +466,9 @@ sub _scan_file {
         if ($self->{_break_camelcased_and_underscored}) {
             my @brokenup = grep $_, split /\W|_|\s+/, $_;
             @clean_words = map {$_ =~ /$_regex/g} @brokenup;
-            @clean_words = grep $_, map {$_ =~ /([[:lower:]0-9]{$min,})/i;$1?"\L$1":''} @clean_words;
+        @clean_words = $self->{_case_sensitive} ? 
+                       grep $_, map {$_ =~ /([[:lower:]0-9]{$min,})/i;$1?$1:''} @clean_words :
+                       grep $_, map {$_ =~ /([[:lower:]0-9]{$min,})/i;$1?"\L$1":''} @clean_words;
         } else {
             my @brokenup = split /\"|\'|\.|\(|\)|\[|\]|\\|\/|\s+/, $_;
             @clean_words = grep $_, map { /([a-z0-9_]{$min,})/i;$1 } @brokenup;
@@ -470,7 +476,11 @@ sub _scan_file {
         next unless @clean_words;
         @clean_words = grep $_, map &simple_stemmer($_), @clean_words
                if $self->{_want_stemming};
-        map { $self->{_vocab_hist}->{$_}++ } grep $_, @clean_words;
+        if ($self->{_case_sensitive}) {
+            map { $self->{_vocab_hist}->{$_}++ } grep $_, @clean_words;
+        } else {
+            map { $self->{_vocab_hist}->{"\L$_"}++ } grep $_, @clean_words;
+        }
         for (@clean_words) { $uniques{$_}++ };
     }
     close( IN );
@@ -478,6 +488,16 @@ sub _scan_file {
     $self->{_total_num_of_docs}++;
 }
 
+sub ok_to_filetype {
+    my $self = shift;    
+    my $filename = shift;
+    my ($base, $dir, $suffix) = fileparse($filename, '\..*');
+    croak "You called this module without specifying the file types in the constructor"
+        unless @{$self->{_file_types}} > 0;
+    return 1 if contained_in($suffix, @{$self->{_file_types}});
+    return 0;
+}
+
 ############################## LSA Modeling and Retrieval ################################
 
 sub construct_lsa_model {
@@ -526,7 +546,6 @@ sub construct_lsa_model {
     # to check the size of, say, U matrix, you would call
     #  my @size = ( $U->getdim(1), $U->getdim(0) );
     #  print "\nsize of U: @size\n";
-
     my $U_trunc = $U->slice("0:$index,:")->sever;
     my $V_trunc = $V->slice("0:$index,0:$index")->sever;    
     $self->{_lsa_vec_truncator} = inv(stretcher($SIGMA_trunc)) x 
@@ -622,20 +641,22 @@ sub _construct_doc_vector {
         return;
     }
     while (<IN>) {
-        chomp;                                                    
+        next if /^[ ]*\r?\n?$/;
+        $_ =~ s/\r?\n?$//;
         my @brokenup = split /\"|\'|\.|\(|\)|\[|\]|\\|\/|\s+/, $_;
         my @clean_words = grep $_, map { /([a-z0-9_]{$min,})/i;$1 } @brokenup;
         next unless @clean_words;
         @clean_words = grep $_, 
                        map &simple_stemmer($_, $self->{_debug}), @clean_words
-               if $self->{_want_stemming};
-        map { $document_vector{"\L$_"}++ } 
-                grep {exists $self->{_vocab_hist}->{"\L$_"}} @clean_words; 
+                       if $self->{_want_stemming};
+        $self->{_case_sensitive} ? 
+            map { $document_vector{$_}++ } grep {exists $self->{_vocab_hist}->{$_}} @clean_words :
+            map { $document_vector{"\L$_"}++ } 
+                                       grep {exists $self->{_vocab_hist}->{"\L$_"}} @clean_words; 
     }
     close IN;
     die "Something went wrong. Doc vector size unequal to vocab size"
         unless $self->{_vocab_size} == scalar(keys %document_vector);
-
     foreach (keys %document_vector) {        
         $total_words_in_doc += $document_vector{$_};
     }
@@ -940,7 +961,6 @@ sub precision_and_recall_calculator {
             }      
         }
         my @relevant_set = values %ranked_relevancies;
-
         warn "\n\nNo relevant docs found for query $query.\n" .
              "Will skip over this query for precision and\n" .
              "recall calculations\n\n" unless @relevant_set;
@@ -1056,6 +1076,8 @@ sub _check_for_illegal_params {
                             normalized_doc_vecs_db
                             use_idf_filter
                             stop_words_file
+                            file_types
+                            case_sensitive
                             max_number_retrievals
                             query_file
                             relevancy_file
@@ -1196,13 +1218,15 @@ algorithms in response to search words and phrases.
         my @query = qw/ program ListIterator add ArrayList args /;
         my $stop_words_file = "stop_words.txt";  
         my $vsm = Algorithm::VSM->new( 
-                           corpus_directory         => $corpus_dir,
-                           use_idf_filter           => 1,
-                           stop_words_file          => $stop_words_file,
-                           max_number_retrievals    => 10,
-                           want_stemming            => 1,  
-                           min_word_length          => 4,
-                           break_camelcased_and_underscored  => 1, 
+                            break_camelcased_and_underscored  => 1, 
+                            case_sensitive         => 0,
+                            corpus_directory       => $corpus_dir,
+                            file_types             => ['.txt', '.java'],
+                            max_number_retrievals  => 10,
+                            min_word_length        => 4,
+                            stop_words_file        => $stop_words_file,
+                            use_idf_filter         => 1,
+                            want_stemming          => 1,
         );
         $vsm->get_corpus_vocabulary_and_word_counts();
         $vsm->display_corpus_vocab();
@@ -1215,18 +1239,12 @@ algorithms in response to search words and phrases.
         my $retrievals = $vsm->retrieve_for_query_with_vsm( \@query );
         $vsm->display_retrievals( $retrievals );
 
-     The constructor parameter 'corpus_directory' is for naming the root of the
-     directory whose VSM model you wish to construct.  The parameter 'want_stemming'
-     means that you would want the words in the documents to be stemmed to their root
-     forms before the VSM model is constructed.  Stemming will reduce all words such
-     as 'programming,' 'programs,' 'program,' etc. to the same root word 'program.'
-     The parameter 'break_camelcased_and_underscored' when set will cause all
-     underscored and camel-cased words to be split.  The constructor parameter
-     'min_word_length' causes all words to be discarded whose lengths are shorter
-     than the value given to this parameter.  The functions display_corpus_vocab()
-     and display_doc_vectors() are there only for testing purposes with small
-     corpora.  If you must use them for large libraries/corpora, you might wish to
-     redirect the output to a file.
+     The purpose of each constructor option and what is accomplished by the method
+     calls should be obvious by their names.  If not, they are explained in greater
+     detail elsewhere in this documentation page.  Note that the methods
+     display_corpus_vocab() and display_doc_vectors() are there only for testing
+     purposes with small corpora.  If you must use them for large libraries/corpora,
+     you might wish to redirect the output to a file.
 
      By default, a call to a constructor calculates normalized term-frequency vectors
      for the documents.  Normalization consists of first calculating the term
@@ -1240,14 +1258,16 @@ algorithms in response to search words and phrases.
   # FOR CONSTRUCTING AN LSA MODEL FOR RETRIEVAL:
 
         my $lsa = Algorithm::VSM->new( 
-                           corpus_directory         => $corpus_dir,
-                           use_idf_filter           => 1,
-                           stop_words_file          => $stop_words_file,
-                           want_stemming            => 1,
-                           break_camelcased_and_underscored  => 1, 
-                           min_word_length          => 4,
-                           lsa_svd_threshold        => 0.01, 
-                           max_number_retrievals    => 10,
+                            break_camelcased_and_underscored  => 1, 
+                            case_sensitive         => 0,
+                            corpus_directory       => $corpus_dir,
+                            file_types             => ['.txt', '.java'],
+                            lsa_svd_threshold      => 0.01, 
+                            max_number_retrievals  => 10,
+                            min_word_length        => 4,
+                            stop_words_file        => $stop_words_file,
+                            use_idf_filter         => 1,
+                            want_stemming          => 1,
         );
         $lsa->get_corpus_vocabulary_and_word_counts();
         $lsa->display_corpus_vocab();
@@ -1276,16 +1296,17 @@ algorithms in response to search words and phrases.
         my $relevancy_file   = "relevancy.txt";   # All relevancy judgments
                                                   # will be stored in this file
         my $vsm = Algorithm::VSM->new( 
-                           corpus_directory    => $corpus_dir,
-                           stop_words_file     => $stop_words_file,
-                           query_file          => $query_file,
-                           want_stemming       => 1
-                           min_word_length     => 4,
-                           relevancy_threshold => 5, 
-                           break_camelcased_and_underscored  => 1, 
-                           relevancy_file      => $relevancy_file, 
+                            break_camelcased_and_underscored  => 1, 
+                            case_sensitive         => 0,
+                            corpus_directory       => $corpus_dir,
+                            file_types             => ['.txt', '.java'],
+                            min_word_length        => 4,
+                            query_file             => $query_file,
+                            relevancy_file         => $relevancy_file,
+                            relevancy_threshold    => 5, 
+                            stop_words_file        => $stop_words_file, 
+                            want_stemming          => 1,
         );
-
         $vsm->get_corpus_vocabulary_and_word_counts();
         $vsm->generate_document_vectors();
         $vsm->estimate_doc_relevancies();
@@ -1309,17 +1330,18 @@ algorithms in response to search words and phrases.
   # FOR MEASURING PRECISION VERSUS RECALL FOR LSA:
 
         my $lsa = Algorithm::VSM->new( 
-                           corpus_directory    => $corpus_dir,
-                           stop_words_file     => $stop_words_file,
-                           query_file          => $query_file,
-                           want_stemming       => 1,
-                           lsa_svd_threshold   => 0.01,
-                           relevancy_threshold => 5,
-                           break_camelcased_and_underscored  => 1, 
-                           min_word_length     => 4,
-                           relevancy_file      => $relevancy_file,
+                            break_camelcased_and_underscored  => 1, 
+                            case_sensitive         => 0,
+                            corpus_directory       => $corpus_dir,
+                            file_types             => ['.txt', '.java'],
+                            lsa_svd_threshold      => 0.01,
+                            min_word_length        => 4,
+                            query_file             => $query_file,
+                            relevancy_file         => $relevancy_file,
+                            relevancy_threshold    => 5, 
+                            stop_words_file        => $stop_words_file, 
+                            want_stemming          => 1,
         );
-
         $lsa->get_corpus_vocabulary_and_word_counts();
         $lsa->generate_document_vectors();
         $lsa->construct_lsa_model();
@@ -1349,13 +1371,15 @@ algorithms in response to search words and phrases.
         my $query_file      = "test_queries.txt";
         my $relevancy_file   = "relevancy.txt";  
         my $vsm = Algorithm::VSM->new( 
-                   corpus_directory    => $corpus_dir,
-                   stop_words_file     => $stop_words_file,
-                   query_file          => $query_file,
-                   want_stemming       => 1,
-                   min_word_length     => 4,
-                   break_camelcased_and_underscored  => 1, 
-                   relevancy_file      => $relevancy_file,
+                            break_camelcased_and_underscored  => 1, 
+                            case_sensitive         => 0,
+                            corpus_directory       => $corpus_dir,
+                            file_types             => ['.txt', '.java'],
+                            min_word_length        => 4,
+                            query_file             => $query_file,
+                            relevancy_file         => $relevancy_file,
+                            stop_words_file        => $stop_words_file, 
+                            want_stemming          => 1,
         );
         $vsm->get_corpus_vocabulary_and_word_counts();
         $vsm->generate_document_vectors();
@@ -1380,16 +1404,17 @@ algorithms in response to search words and phrases.
         my $query_file      = "test_queries.txt";
         my $relevancy_file   = "relevancy.txt";  
         my $lsa = Algorithm::VSM->new( 
-                   corpus_directory    => $corpus_dir,
-                   stop_words_file     => $stop_words_file,
-                   query_file          => $query_file,
-                   want_stemming       => 1,
-                   min_word_length     => 4,
-                   lsa_svd_threshold   => 0.01,
-                   break_camelcased_and_underscored  => 1, 
-                   relevancy_file      => $relevancy_file,
+                            break_camelcased_and_underscored  => 1,  
+                            case_sensitive      => 0,                
+                            corpus_directory    => $corpus_dir,
+                            file_types          => ['.txt', '.java'],
+                            lsa_svd_threshold   => 0.01,
+                            min_word_length     => 4,
+                            query_file          => $query_file,
+                            relevancy_file      => $relevancy_file,
+                            stop_words_file     => $stop_words_file,
+                            want_stemming       => 1,                
         );
-
         $lsa->get_corpus_vocabulary_and_word_counts();
         $lsa->generate_document_vectors();
         $lsa->upload_document_relevancies_from_file();  
@@ -1412,10 +1437,13 @@ algorithms in response to search words and phrases.
         my $corpus_dir = "corpus";
         my $stop_words_file = "stop_words.txt";
         my $vsm = Algorithm::VSM->new(
+                   break_camelcased_and_underscored  => 1,  
+                   case_sensitive           => 0,           
                    corpus_directory         => $corpus_dir,
+                   file_types               => ['.txt', '.java'],
+                   min_word_length          => 4,
                    stop_words_file          => $stop_words_file,
-                   want_stemming            => 1,
-                   break_camelcased_and_underscored  => 1, 
+                   want_stemming            => 1,           
         );
         $vsm->get_corpus_vocabulary_and_word_counts();
         $vsm->generate_document_vectors();
@@ -1429,6 +1457,16 @@ algorithms in response to search words and phrases.
 
 =head1 CHANGES
 
+Version 1.61 improves the implementation of the directory scanner to make it more
+platform independent.  Additionally, you are now required to specify in the
+constructor call the file types to be considered for computing the database model.
+If, say, you have a large software library and you want only Java and text files to
+be scanned for creating the VSM (or the LSA) model, you must supply that information
+to the module by setting the constructor parameter C<file_types> to the anonymous
+list C<['.java', '.txt']>.  An additional constructor parameter introduced in this
+version is C<case_sensitive>.  If you set it to 1, that will force the database model
+and query matching to become case sensitive.
+
 Version 1.60 reflects the fact that people are now more likely to use this module by
 keeping the model constructed for a corpus in the fast memory (as opposed to storing
 the models in disk-based hash tables) for its repeated invocation for different
@@ -1607,9 +1645,11 @@ A call to C<new()> constructs a new instance of the C<Algorithm::VSM> class:
 
     my $vsm = Algorithm::VSM->new( 
                      break_camelcased_and_underscored  => 1, 
+                     case_sensitive         => 0,
                      corpus_directory       => "",
                      corpus_vocab_db        => "corpus_vocab_db",
                      doc_vectors_db         => "doc_vectors_db",
+                     file_types             => $my_file_types,
                      lsa_svd_threshold      => 0.01, 
                      max_number_retrievals  => 10,
                      min_word_length        => 4,
@@ -1624,8 +1664,10 @@ A call to C<new()> constructs a new instance of the C<Algorithm::VSM> class:
               );       
 
 The values shown on the right side of the big arrows are the B<default values for the
-parameters>.  The following nested list will now describe each of the constructor
-parameters:
+parameters>.  The value supplied through the variable C<$my_file_types> would be
+something like C<['.java', '.txt']> if, say, you wanted only Java and text files to
+be included in creating the database model.  The following nested list will now
+describe each of the constructor parameters shown above:
 
 =over 16
 
@@ -1649,6 +1691,13 @@ Once a disk-based VSM model is created and stored away in the file named by this
 parameter and the parameter to be described next, it can subsequently be used
 directly for speedier retrieval.
 
+=item I<case_sensitive:>
+
+When set to 1, this parameter forces the module to maintain the case of the terms in
+the corpus files when creating the vocabulary and the document vectors.  Setting
+C<case_sensitive> to 1 also causes the query matching to become case sensitive.
+(This constructor parameter was introduced in Version 1.61.)
+
 =item I<doc_vectors_db:>
 
 The database named by B<doc_vectors_db> stores the document vector representation for
@@ -1656,6 +1705,15 @@ each document in the corpus.  Each document vector has the same size as the
 corpus-wide vocabulary; each element of such a vector is the number of occurrences of
 the word that corresponds to that position in the vocabulary vector.
 
+=item I<file_types:>
+
+This parameter tells the module what types of files in the corpus directory you want
+scanned for creating the database model. The value supplied for this parameter is an
+anonymous list of the file suffixes for the file types.  For example, if you wanted
+only Java and text files to be scanned, you will set this parameter to C<['.java',
+'.txt']>.  The module throws an exception if this parameter is left unspecified.
+(This constructor parameter was introduced in Version 1.61.)
+
 =item I<lsa_svd_threshold:>
 
 The parameter B<lsa_svd_threshold> is used for rejecting singular values that are
@@ -2016,10 +2074,13 @@ This module requires the following modules:
     SDBM_File
     Storable
     PDL
+    File::Basename
+    File::Spec::Functions
 
 The first two of these are needed for creating disk-based database records for the
 VSM and LSA models.  The third is needed for calculating the SVD of the
-term-frequency matrix. (PDL stands for Perl Data Language.)
+term-frequency matrix. (PDL stands for Perl Data Language.)  The last two are needed
+by the directory scanner to make pathnames platform independent.
 
 =head1 EXAMPLES
 
@@ -2177,10 +2238,10 @@ the string 'VSM' in the subject line to get past my spam filter.
 Download the archive from CPAN in any directory of your choice.  Unpack the archive
 with a command that on a Linux machine would look like:
 
-    tar zxvf Algorithm-VSM-1.60.tar.gz
+    tar zxvf Algorithm-VSM-1.61.tar.gz
 
 This will create an installation directory for you whose name will be
-C<Algorithm-VSM-1.60>.  Enter this directory and execute the following commands for a
+C<Algorithm-VSM-1.61>.  Enter this directory and execute the following commands for a
 standard install of the module if you have root privileges:
 
     perl Makefile.PL
